package com.shkj.system.mapper;

import java.util.List;
import com.shkj.system.domain.SysParameter;
import org.apache.ibatis.annotations.Param;

/**
 * 参数配置 数据层
 * 
 * @author lch
 */
public interface SysParameterMapper
{
    /**
     * 查询参数配置信息
     * 
     * @param config 参数配置信息
     * @return 参数配置信息
     */
    public SysParameter selectConfig(SysParameter config);

    /**
     * 查询参数配置列表
     * 
     * @param config 参数配置信息
     * @return 参数配置集合
     */
    public List<SysParameter> selectConfigList(SysParameter config);

    /**
     * 根据键名查询参数配置信息
     * 
     * @param paraCode 参数键名
     * @param branchId
     * @return 参数配置信息
     */
    public SysParameter checkConfigKeyUnique(@Param("paraCode") String paraCode, @Param("branchId") Long branchId);

    /**
     * 新增参数配置
     * 
     * @param config 参数配置信息
     * @return 结果
     */
    public int insertConfig(SysParameter config);

    /**
     * 修改参数配置
     * 
     * @param config 参数配置信息
     * @return 结果
     */
    public int updateConfig(SysParameter config);

    /**
     * 删除参数配置
     * 
     * @param id 参数ID
     * @return 结果
     */
    public int deleteConfigById(Long id);

    /**
     * 批量删除参数信息
     * 
     * @param configIds 需要删除的参数ID
     * @return 结果
     */
    public int deleteConfigByIds(Long[] configIds);
}
